@@ -989,6 +989,11 @@ def rs_nth_root(p, n, x, prec):
             except ValueError:                # as exponent
                 raise DomainError("The given series can't be expanded in "
                     "this domain.")
+            except TypeError:
+                try:
+                    const = R(c**QQ(1, n))
+                except ValueError:
+                    raise DomainError("The given series can't be expanded in this domain.")
         res = rs_nth_root(p/c, n, x, prec)*const
     else:
         res = _nth_root1(p, n, x, prec)
